@@ -6,7 +6,7 @@ test_that("rm_nchar_words is removing/replacing nchar_words strings",{
     
     x2 <- "there in Mike's re'y."
 
-    expect_true(identical(rm_nchar_words(x, 4), x2))	
+    expect_equivalent(rm_nchar_words(x, 4), x2)	
 	
 })
 
@@ -17,8 +17,7 @@ test_that("rm_nchar_words is extracting nchar_words strings",{
 
     x3 <- list(c("This", "Jon's", "dogs'", "'bout", "word")) 
 
-    expect_true(identical(rm_nchar_words(x, 4, extract=TRUE), x3))
+    expect_equivalent(rm_nchar_words(x, 4, extract=TRUE), x3)
 })
 
 
-
